@@ -12,6 +12,7 @@
 
     #include "RJSWrapperObj.h"
   
+    #ifdef QT_PRINTSUPPORT_LIB
         #include <QPaintEngine>
       
         #include <QPrintEngine>
@@ -1912,5 +1913,7 @@ DuplexShortSide = QPrinter::DuplexShortSide,
     Q_DECLARE_INTERFACE(QPrinter_Wrapper, "org.qcad.QPrinter_Wrapper")
 
   
+    #endif
+  
   #endif
   
