@@ -8,4 +8,7 @@
   #include "qquickview_base.h"
   //#include "qquickview_wrapper.h"
   //#include "header_cpp.h"
-    
\ No newline at end of file
+    
+    #ifdef QT_QUICK_LIB
+    #endif
+  
\ No newline at end of file
